@@ -9,7 +9,7 @@
 package WebService::HashiCorp::Vault;
 
 use Moo;
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 extends 'WebService::HashiCorp::Vault::Base';
 use namespace::clean;
@@ -50,6 +50,7 @@ sub secret {
     my %args = @_;
     $args{token}   = $self->token();
     $args{version} = $self->version();
+    $args{path}    = $self->path();
     $args{backend} ||= 'generic';
     die sprintf( "Unknown backend type: %s\n", $args{backend} )
         unless $backendmap{ lc($args{backend}) };
@@ -85,7 +86,7 @@ WebService::HashiCorp::Vault - Perl API for HashiCorp's Vault
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -94,8 +95,7 @@ version 0.002
  my $vault = WebService::HashiCorp::Vault->new(
      token    => 'xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx',
      base_url => 'http://127.0.0.1:8200', # optional, default shown
-     verson   => 'v1', # optional, for future use if api changes
-
+     version  => 'v1', # optional, for future use if api changes
  );
 
  my $secret = $vault->secret();
@@ -124,6 +124,7 @@ Unfortunatly the "official" API's for other languages aren't much to go on. They
  my $secret = $vault->secret(
      mount   => 'secret', # optional if mounted non-default
      backend => 'Generic', # or MySQL, or SSH, or whatever
+     path    => 'my_service' # optional secret path
  );
 
 B<Parameters>
